@@ -1,6 +1,8 @@
 """Test for libtmux Server object."""
 import logging
 
+import pytest
+
 from libtmux.common import has_gte_version
 from libtmux.server import Server
 from libtmux.session import Session
@@ -9,7 +11,7 @@ logger = logging.getLogger(__name__)
 
 
 def test_has_session(server: Server, session: Session) -> None:
-    session_name = session.get("session_name")
+    session_name = session.session_name
     assert session_name is not None
     assert server.has_session(session_name)
     assert not server.has_session("asdf2314324321")
@@ -85,14 +87,14 @@ def test_show_environment_not_set(server: Server) -> None:
 def test_new_session(server: Server) -> None:
     """Server.new_session creates and returns valid session"""
     mysession = server.new_session("test_new_session")
-    assert mysession.get("session_name") == "test_new_session"
+    assert mysession.session_name == "test_new_session"
     assert server.has_session("test_new_session")
 
 
 def test_new_session_no_name(server: Server) -> None:
     """Server.new_session works with no name"""
     first_session = server.new_session()
-    first_session_name = first_session.get("session_name")
+    first_session_name = first_session.session_name
     assert first_session_name is not None
     assert server.has_session(first_session_name)
 
@@ -100,7 +102,7 @@ def test_new_session_no_name(server: Server) -> None:
 
     # When a new session is created, it should enumerate
     second_session = server.new_session()
-    second_session_name = second_session.get("session_name")
+    second_session_name = second_session.session_name
     assert expected_session_name == second_session_name
     assert second_session_name is not None
     assert server.has_session(second_session_name)
@@ -111,15 +113,46 @@ def test_new_session_shell(server: Server) -> None:
     specified command"""
     cmd = "sleep 1m"
     mysession = server.new_session("test_new_session", window_command=cmd)
-    window = mysession.list_windows()[0]
-    pane = window.list_panes()[0]
-    assert mysession.get("session_name") == "test_new_session"
+    window = mysession.windows[0]
+    pane = window.panes[0]
+    assert mysession.session_name == "test_new_session"
     assert server.has_session("test_new_session")
 
-    pane_start_command = pane.get("pane_start_command")
+    pane_start_command = pane.pane_start_command
     assert pane_start_command is not None
 
     if has_gte_version("3.2"):
         assert pane_start_command.replace('"', "") == cmd
     else:
         assert pane_start_command == cmd
+
+
+def test_no_server_sessions() -> None:
+    server = Server(socket_name="test_attached_session_no_server")
+    assert server.sessions == []
+
+
+def test_no_server_attached_sessions() -> None:
+    server = Server(socket_name="test_no_server_attached_sessions")
+    assert server.attached_sessions == []
+
+
+def test_no_server_is_alive() -> None:
+    dead_server = Server(socket_name="test_no_server_is_alive")
+    assert not dead_server.is_alive()
+
+
+def test_with_server_is_alive(server: Server) -> None:
+    server.new_session()
+    assert server.is_alive()
+
+
+def test_no_server_raise_if_dead() -> None:
+    dead_server = Server(socket_name="test_attached_session_no_server")
+    with pytest.raises(Exception):
+        dead_server.raise_if_dead()
+
+
+def test_with_server_raise_if_dead(server: Server) -> None:
+    server.new_session()
+    server.raise_if_dead()
